@@ -65,14 +65,13 @@ class CIMTestTemplates(object):
         test_helper = FieldTestHelper(
             splunk_search_util, cim_fields, interval=splunk_search_util.search_interval, retries=splunk_search_util.search_retry
         )
-        record_property("search", base_search)
         record_property("tag_stanza", cim_tag_stanza)
         record_property("data_model", cim_data_model)
         record_property("data_set", data_set)
         record_property("fields", cim_single_field)
         record_property("fields_type", cim_fields_type)       
         # Execute the query and get the results
-        results = test_helper.test_field(base_search)
+        results = test_helper.test_field(base_search, record_property)
 
         # All assertion are made in the same tests to make the test report with
         # very clear order of scenarios. with this approach, a user will be able to identify
